"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useExportConnections = void 0;
const react_1 = require("react");
const common_1 = require("./common");
const renderer_1 = require("@mongodb-js/connection-storage/renderer");
const fs_1 = require("fs");
const provider_1 = require("compass-preferences-model/provider");
const INITIAL_STATE = Object.freeze({
    ...common_1.COMMON_INITIAL_STATE,
    removeSecrets: false,
});
function connectionInfosToConnectionShortInfos(infos, existingShortInfoList) {
    return infos.map((conn) => ({
        id: conn.id,
        name: conn.favorite?.name ?? '',
        selected: existingShortInfoList?.find(({ id }) => id === conn.id)?.selected ?? true,
    }));
}
function useExportConnections({ finish, favoriteConnections, open, trackingProps, }, exportConnections = renderer_1.ConnectionStorage.exportConnections.bind(renderer_1.ConnectionStorage)) {
    const [state, setState] = (0, react_1.useState)(INITIAL_STATE);
    (0, react_1.useEffect)(() => setState(INITIAL_STATE), [open]);
    const { passphrase, filename, connectionList, removeSecrets } = state;
    (0, react_1.useEffect)(() => {
        if (favoriteConnections.map(({ id }) => id).join(',') !==
            state.connectionList.map(({ id }) => id).join(',')) {
            setState((prevState) => ({
                ...prevState,
                connectionList: connectionInfosToConnectionShortInfos(favoriteConnections, state.connectionList),
            }));
        }
    }, [favoriteConnections, state.connectionList]);
    const protectConnectionStrings = !!(0, provider_1.usePreference)('protectConnectionStrings');
    (0, react_1.useEffect)(() => {
        if (protectConnectionStrings) {
            setState((prevState) => ({ ...prevState, removeSecrets: true }));
        }
    }, [protectConnectionStrings, state.removeSecrets]);
    const { onChangeConnectionList, onChangePassphrase, onCancel } = (0, common_1.useImportExportConnectionsCommon)(setState, finish);
    const onSubmit = (0, react_1.useCallback)(() => {
        setState((prevState) => ({ ...prevState, inProgress: true }));
        void (async () => {
            const filterConnectionIds = connectionList
                .filter((x) => x.selected)
                .map((x) => x.id);
            const passphrase = removeSecrets ? '' : state.passphrase;
            try {
                const fileContents = await exportConnections({
                    options: {
                        passphrase,
                        filterConnectionIds,
                        trackingProps,
                        removeSecrets,
                    },
                });
                await fs_1.promises.writeFile(filename, fileContents);
            }
            catch (err) {
                setState((prevState) => {
                    return {
                        ...prevState,
                        inProgress: false,
                        error: err.message,
                    };
                });
                return;
            }
            finish('succeeded');
        })();
    }, [connectionList, passphrase, removeSecrets, filename, finish]);
    const onChangeFilename = (0, react_1.useCallback)((filename) => {
        setState((prevState) => ({
            ...prevState,
            filename,
            ...(filename !== prevState.filename && { error: '' }),
        }));
    }, []);
    const onChangeRemoveSecrets = (0, react_1.useCallback)((evt) => {
        setState((prevState) => ({
            ...prevState,
            removeSecrets: evt.target.checked || protectConnectionStrings,
        }));
    }, [protectConnectionStrings]);
    return {
        onCancel,
        onSubmit,
        onChangeFilename,
        onChangePassphrase,
        onChangeConnectionList,
        onChangeRemoveSecrets,
        state,
    };
}
exports.useExportConnections = useExportConnections;
//# sourceMappingURL=use-export.js.map